package com.winhc.config;

import org.neo4j.driver.*;

import static org.neo4j.driver.Values.parameters;

public class DemoNeo4j implements AutoCloseable {
    private final Driver driver;

    public DemoNeo4j(String uri, String user, String password) {
        driver = GraphDatabase.driver(uri, AuthTokens.basic(user, password));
    }

    @Override
    public void close() throws Exception {
        driver.close();
    }

    public void printGreeting(final String message) {
        try (Session session = driver.session()) {
            String greeting = session.writeTransaction(new TransactionWork<String>() {
                @Override
                public String execute(Transaction tx) {
                    Result result = tx.run("CREATE (a:Greeting) " +
                                    "SET a.message = $message " +
                                    "RETURN a.message + ', from node ' + id(a)",
                            parameters("message", message));
                    return result.single().get(0).asString();
                }
            });
            System.out.println(greeting);
        }
    }

    public static void main(String... args) throws Exception {
        try (DemoNeo4j greeter = new DemoNeo4j("bolt://106.14.211.187:7687", "neo4j", "neo4j168")) {
            greeter.printGreeting("hello, world");
        }
    }
}