package com.winhc.utils;

import cn.hutool.json.JSONUtil;
import com.winhc.common.enums.CompanyEnum;
import com.winhc.db.mongodb.dataobject.NodeRelationError;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.neo4j.driver.Result;
import org.neo4j.driver.Session;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author π
 * @Description:
 * @date 2021/1/11 21:31
 */
public class CompanyUtils {
    public static List<Map<String, Object>> map(List<ConsumerRecord<?, ?>> records) {
        return records.stream().filter(r -> (r != null && r.value() != null)).map(r -> {
            Map<String, Object> m = JSONUtil.parseObj(r.value().toString());
            return m;
        }).collect(Collectors.toList());
    }

    public static List<Map<String, Object>> filterList(List<Map<String, Object>> list, String type) {
        return list.stream().filter(r -> (r.getOrDefault("topic_type","-1").equals(type))).collect(Collectors.toList());
    }

    public static List<NodeRelationError> toMessage(List<ConsumerRecord> records, String errorMessage) {
        return records.stream().filter(r -> (r != null && r.value() != null)).map(r -> {
            String consumerMessage = r.value().toString();
            Map<String, Object> m = JSONUtil.parseObj(consumerMessage);
            Object topic_type = m.getOrDefault("topic_type", "-1");
            Date date = new Date();
            NodeRelationError n1 = new NodeRelationError();
            n1.setCreateTime(date);
            n1.setUpdateTime(date);
            n1.setConsumerMessage(consumerMessage);
            n1.setErrorMessage(errorMessage);
            n1.setStatus(0);
            n1.setTopicType(String.valueOf(topic_type));
            return n1;
        }).collect(Collectors.toList());
    }

    public static String writeNeo4j(Session session, String cql, HashMap<String,Object> parameters) {
        String data = session.writeTransaction(tx -> {
            Result result = tx.run(cql, parameters);
            return "success";
        });
        return data;
    }

    public static String getIncrPersonLabel(){
        return CompanyEnum.Lable.新增.code +DateUtil.getDateBefore(-1).replace("-", "");
    }

    public static void main(String[] args) {
        System.out.println(getIncrPersonLabel());
    }
}
